pub struct Input {
pub start: Option<FHIRDate>,
pub end: Option<FHIRDate>,
pub _since: Option<FHIRInstant>,
pub _type: Option<Vec<FHIRCode>>,
pub _count: Option<FHIRInteger>,
}Fields
start: Option<FHIRDate>The date range relates to care dates, not record currency dates - e.g. all records relating to care provided in a certain date range. If no start date is provided, all records prior to the end date are in scope.
end: Option<FHIRDate>The date range relates to care dates, not record currency dates - e.g. all records relating to care provided in a certain date range. If no end date is provided, all records subsequent to the start date are in scope.
_since: Option<FHIRInstant>Resources updated after this period will be included in the response. The intent of this parameter is to allow a client to request only records that have changed since the last request, based on either the return header time, or or (for asynchronous use), the transaction time
_type: Option<Vec<FHIRCode>>One or more parameters, each containing one or more comma-delimited FHIR resource types to include in the return resources. In the absence of any specified types, the server returns all resource types
_count: Option<FHIRInteger>See discussion below on the utility of paging through the results of the $everything operation